from nocasedict import NoCaseDict
from regexpdict import RegexpDict
from sorteddict import *
from dict import Dict

__author__ = "Miguel Olivares"
__email__ = "miguel@moliware.com"
__version__ = '0.3.1'